@@ -1,7 +1,7 @@
 #ifndef _QEAUDIOFORMATDIALOG_H
 #define _QEAUDIOFORMATDIALOG_H
 
-#include <ecasound/eca-audio-format.h>
+#include <eca-audio-format.h>
 #include "qeinput.h"
 
 class QSpinBox;
