@@ -6,7 +6,7 @@
 #include <qdialog.h>
 #include <qwidget.h>
 
-#include <ecasound/eca-chainop.h>
+#include <eca-chainop.h>
 
 #include "qechainoperatorinput.h"
 #include "qenonblockingevent.h"
@@ -35,7 +35,7 @@ private:
   void init_layout(void);
 
   ECA_CONTROL* ectrl;
-  string input_rep, output_rep;
+  string input_rep, output_rep, preview_output_rep;
   long int start_pos_rep;
   long int length_rep;
   QEChainOperatorInput* copinput;
@@ -49,6 +49,7 @@ public:
   QEChainopEvent (ECA_CONTROL* ctrl, 
 		  const string& input,
 		  const string& output,
+		  const string& preview_output,
 		  long int start_pos, 
 		  long int length,
 		  QWidget *parent = 0, 
