@@ -17,8 +17,12 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 // ------------------------------------------------------------------------
 
+#include <string>
+
 #include "qecopyevent.h"
 
+using std::string;
+
 QECopyEvent::QECopyEvent(ECA_CONTROL* ctrl,
 			 const string& input,
 			 const string& output,
@@ -31,7 +35,9 @@ QECopyEvent::QECopyEvent(ECA_CONTROL* ctrl,
   init("copyevent", "default");
   set_input(input);
   set_input_position(start_pos);
-  set_length(length);
+  if (length > 0) {
+    set_length(length);
+  }
   set_default_audio_format(input);
   ectrl->set_chainsetup_parameter("-x");
   set_output(output);
