@@ -1,7 +1,7 @@
 // ------------------------------------------------------------------------
 // qeevent.cpp: Virtual base for classes representing libecasound
 //              processing events
-// Copyright (C) 1999-2000 Kai Vehmanen (kaiv@wakkanet.fi)
+// Copyright (C) 1999-2002 Kai Vehmanen (kai.vehmanen@wakkanet.fi)
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -18,21 +18,25 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 // ------------------------------------------------------------------------
 
+#include <iostream>
+#include <string>
+
 #include <qprogressdialog.h>
-#include <ecasound/eca-error.h>
+#include <qmessagebox.h>
+
+#include <kvu_numtostr.h>
+#include <eca-error.h>
 
 #include "qeevent.h"
 
+using std::cerr;
+using std::endl;
+using std::string;
+
 QEEvent::QEEvent(ECA_CONTROL* ctrl) 
   : info_string_rep("Processing..."),
-    ectrl(ctrl) {
-#ifdef NDEBUG
-  ecadebug->set_debug_level(0);
-#else
-  ecadebug->set_debug_level(ECA_DEBUG::info |
-			    ECA_DEBUG::module_flow |
-			    ECA_DEBUG::user_objects);
-#endif
+    ectrl(ctrl) 
+{
 }
 
 QEEvent::~QEEvent(void) { 
@@ -46,13 +50,13 @@ QEEvent::~QEEvent(void) {
 
 void QEEvent::init(const string& chainsetup, const string& chain) {
   // --------
-  REQUIRE(ectrl != 0);
+  DBC_REQUIRE(ectrl != 0);
   // --------
 
   triggered_rep = false;
-  input_object = 0;
-  output_object = 0;
-  ectrl->toggle_interactive_mode(true);
+  result_rep = true;
+  input_object_repp = 0;
+  output_object_repp = 0;
 
   if (ectrl->is_running() == true) ectrl->stop();
   if (ectrl->is_connected() == true) ectrl->disconnect_chainsetup();
@@ -71,19 +75,28 @@ void QEEvent::init(const string& chainsetup, const string& chain) {
   initialized_cs_rep = chainsetup;
 
   // --------
-  ENSURE(ectrl->selected_chainsetup() == initialized_cs_rep);
+  DBC_ENSURE(ectrl->selected_chainsetup() == initialized_cs_rep);
   // --------
 }
 
 void QEEvent::blocking_start(void) {
   // --------
-  REQUIRE(ectrl->is_valid() == true);
-  REQUIRE(ectrl->is_selected() == true);
-  REQUIRE(is_triggered() == false);
+  DBC_REQUIRE(ectrl->is_valid() == true);
+  DBC_REQUIRE(ectrl->is_selected() == true);
+  DBC_REQUIRE(is_triggered() == false);
   // --------
 
   try {
     ectrl->connect_chainsetup();
+    if (ectrl->is_connected() != true) {
+      QMessageBox* mbox = new QMessageBox(0, "mbox");
+      mbox->information(0, "ecawave", QString("Error during operation!"), 0);
+      toggle_result(false);
+      return;
+    }
+    
+    set_audio_object_params();
+
     ectrl->start();
     toggle_triggered_state(true);
 
@@ -92,12 +105,14 @@ void QEEvent::blocking_start(void) {
     sleepcount.tv_nsec = 20000000;
     
     int progress_length = static_cast<int>(ectrl->length_in_seconds_exact() * 10.0);
-    if (progress_length == 0 && input_object != 0) 
-      progress_length = static_cast<int>(input_object->length_in_seconds_exact() * 10.0);
+    if (progress_length == 0 && input_object_repp != 0) 
+      progress_length = static_cast<int>(input_object_repp->length_in_seconds_exact() * 10.0);
+    if (progress_length == 0) progress_length = (1 << 23);
+      
     double progress_start = ectrl->position_in_seconds_exact();
 
     QProgressDialog progress (status_info().c_str(), 0,
-			      progress_length - progress_start * 10, 0, 0, true);
+			      static_cast<int>(progress_length - progress_start * 10), 0, 0, true);
 
     progress.setProgress(0);
     progress.show();
@@ -106,66 +121,61 @@ void QEEvent::blocking_start(void) {
       progress.setProgress(static_cast<int>((ectrl->position_in_seconds_exact() - progress_start) * 10.0));
     }
     toggle_triggered_state(false);
+    toggle_result(true);
   }
   catch(ECA_ERROR& e) {
     cerr << "---\nlibecasound error while processing event: [" << e.error_section() << "] : \"" << e.error_message() << "\"\n\n";
+    toggle_result(false);
   }
 
   // --------
-  ENSURE(is_triggered() == false);
+  DBC_ENSURE(is_triggered() == false);
   // --------
 }
 
 void QEEvent::nonblocking_start(void) {
   // --------
-  REQUIRE(ectrl->is_valid() == true);
-  REQUIRE(ectrl->is_selected() == true);
-  REQUIRE(is_triggered() == false);
+  DBC_REQUIRE(ectrl->is_valid() == true);
+  DBC_REQUIRE(ectrl->is_selected() == true);
+  DBC_REQUIRE(is_triggered() == false);
   // --------
 
   ectrl->connect_chainsetup();
+  if (ectrl->is_connected() != true) {
+    QMessageBox* mbox = new QMessageBox(0, "mbox");
+    mbox->information(0, "ecawave", QString("Error during operation!"), 0);
+    toggle_result(false);
+    return;
+  }
+
+  set_audio_object_params();
+
   ectrl->start();
   toggle_triggered_state(true);
+  toggle_result(true);
 
   // --------
-  ENSURE(is_triggered() == true || ectrl->is_running() == false);
-  // --------
-}
-
-void QEEvent::set_input(const string& name) {
-  // --------
-  REQUIRE(name.empty() == false);
-  // --------
-  try {
-    ectrl->add_audio_input(name);
-    input_object = ectrl->get_audio_input();
-  }
-  catch(ECA_ERROR& e) {
-    cerr << "---\nlibecasound error while setting event input: [" << e.error_section() << "] : \"" << e.error_message() << "\"\n\n";
-  }
-
-  // --------
-  ENSURE(input_object != 0);
+  DBC_ENSURE(is_triggered() == true || ectrl->is_running() == false);
   // --------
 }
 
 void QEEvent::set_default_audio_format(const string& name) {
   // --------
-  REQUIRE(name.empty() == false);
+  DBC_REQUIRE(name.empty() == false);
   // --------
   try {
-    ECA_AUDIO_FORMAT aio_params;
     ectrl->select_audio_input(name);
     if (ectrl->get_audio_input() != 0)
-      aio_params = ectrl->get_audio_format(ectrl->get_audio_input());
+      ectrl->set_default_audio_format_to_selected_input();
     else {
       ectrl->select_audio_output(name);
       if (ectrl->get_audio_output() != 0)
-	aio_params = ectrl->get_audio_format(ectrl->get_audio_output());
+	ectrl->set_default_audio_format_to_selected_output();
     }
 
-    ectrl->set_default_audio_format(aio_params);
-    //    cerr << "Setting sample rate of: " << aio_params.samples_per_second() << ".\n";
+    ECA_AUDIO_FORMAT aio_params = ectrl->default_audio_format();
+
+    // cerr << "Setting sample rate of: " << aio_params.samples_per_second() << ".\n";
     ectrl->set_chainsetup_parameter("-sr:" + kvu_numtostr(aio_params.samples_per_second()));
   }
   catch(ECA_ERROR& e) {
@@ -173,50 +183,83 @@ void QEEvent::set_default_audio_format(const string& name) {
   }
 }
 
-void QEEvent::set_input_position(long int pos) {
+void QEEvent::set_audio_object_params(void)
+{
+ // --------
+  DBC_REQUIRE(ectrl->is_running() == false);
+  DBC_REQUIRE(input_startpos_rep >= 0);
+  DBC_REQUIRE(output_startpos_rep >= 0);
   // --------
-  REQUIRE(ectrl->is_running() == false);
-  REQUIRE(input_object != 0);
-  REQUIRE(pos >= 0);
+
+  ectrl->select_audio_input(input_name());
+  input_object_repp = ectrl->get_audio_input();
+  DBC_CHECK(input_object_repp != 0);
+  ectrl->command("ai-set-position-samples " + kvu_numtostr(input_startpos_rep));
+
+  ectrl->select_audio_output(output_name());
+  output_object_repp = ectrl->get_audio_output();
+  DBC_CHECK(output_object_repp != 0);
+  ectrl->command("ao-set-position-samples " + kvu_numtostr(output_startpos_rep));
+
   // --------
-  input_object->seek_position_in_samples(pos);
-  // --------
-  ENSURE(pos == input_object->position_in_samples());
+  DBC_ENSURE(input_startpos_rep == input_object_repp->position_in_samples());
+  DBC_ENSURE(output_startpos_rep == output_object_repp->position_in_samples() ||
+	     output_object_repp->supports_seeking() != true);
   // --------
 }
 
-void QEEvent::set_output(const string& name) {
+void QEEvent::set_input(const string& name) {
   // --------
-  REQUIRE(name.empty() == false);
+  DBC_REQUIRE(name.empty() == false);
   // --------
   try {
-    ectrl->add_audio_output(name);
-    ectrl->select_audio_output(name);
-    output_object = ectrl->get_audio_output();
+    ectrl->add_audio_input(name);
+    input_object_repp = ectrl->get_audio_input();
+    DBC_CHECK(input_object_repp != 0);
+    input_name_rep = input_object_repp->label();
   }
   catch(ECA_ERROR& e) {
     cerr << "---\nlibecasound error while setting event input: [" << e.error_section() << "] : \"" << e.error_message() << "\"\n\n";
   }
+
   // --------
-  ENSURE(output_object != 0);
+  DBC_ENSURE(input_object_repp != 0);
   // --------
 }
 
+void QEEvent::set_input_position(long int pos)
+{
+  // --------
+  DBC_REQUIRE(pos >= 0);
+  // --------
+  input_startpos_rep = pos;
+}
+
+void QEEvent::set_output(const string& name) {
+  // --------
+  DBC_REQUIRE(name.empty() == false);
+  // --------
+  try {
+    ectrl->add_audio_output(name);
+    output_object_repp = ectrl->get_audio_output();
+    DBC_CHECK(output_object_repp != 0);
+    output_name_rep = output_object_repp->label();
+  }
+  catch(ECA_ERROR& e) {
+    cerr << "---\nlibecasound error while setting event output: [" << e.error_section() << "] : \"" << e.error_message() << "\"\n\n";
+  }
+}
+
 void QEEvent::set_output_position(long int pos) {
   // --------
-  REQUIRE(ectrl->is_running() == false);
-  REQUIRE(output_object != 0);
-  REQUIRE(pos >= 0);
-  // --------
-  output_object->seek_position_in_samples(pos);
-  // --------
-  ENSURE(pos == output_object->position_in_samples());
+  DBC_REQUIRE(pos >= 0);
   // --------
+  output_startpos_rep = pos;
 }
 
 void QEEvent::set_length(long int pos) {
   // --------
-  REQUIRE(ectrl->is_running() == false);
+  DBC_REQUIRE(ectrl->is_running() == false);
   // --------
   ectrl->set_chainsetup_processing_length_in_samples(pos);
 }
