@@ -1,6 +1,6 @@
 // ------------------------------------------------------------------------
 // qefadeoutevent.cpp: Fade-out effect
-// Copyright (C) 2000 Kai Vehmanen (kaiv@wakkanet.fi)
+// Copyright (C) 2000,2001 Kai Vehmanen (kai.vehmanen@wakkanet.fi)
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 // ------------------------------------------------------------------------
 
-#include <kvutils/kvu_numtostr.h>
-#include <ecasound/eca-chainsetup.h>
-#include <ecasound/sample-specs.h>
+#include <kvu_numtostr.h>
+#include <eca-chainsetup.h>
+#include <sample-specs.h>
 #include "qefadeoutevent.h"
 
 QEFadeOutEvent::QEFadeOutEvent(ECA_CONTROL* ctrl,
@@ -37,13 +37,17 @@ QEFadeOutEvent::QEFadeOutEvent(ECA_CONTROL* ctrl,
   set_default_audio_format(input);
   set_output(output);
   set_output_position(start_pos);
-  long int srate = SAMPLE_SPECS::sample_rate_default;
-  ECA_CHAINSETUP* cs_rep = ectrl->get_chainsetup();
+  long int srate = 0;
+  const ECA_CHAINSETUP* cs_rep = ectrl->get_chainsetup();
   if (cs_rep != 0) {
-    srate = cs_rep->sample_rate();
+    srate = cs_rep->samples_per_second();
+
+    double fade_length = length;
+    fade_length /= srate;
+    ectrl->add_chain_operator("-ea:100");
+    ectrl->add_controller("-kl:1,100,1," + kvu_numtostr(fade_length, 32));
+  }
+  else {
+    // FIXME: print an error!
   }
-  double fade_length = length;
-  fade_length /= srate;
-  ectrl->add_chain_operator("-ea:100");
-  ectrl->add_controller("-kl:1,100,1," + kvu_numtostr(fade_length, 32));
 }
