@@ -1,6 +1,6 @@
 // ------------------------------------------------------------------------
 // qeinterface.cpp: Top-level ecawave interface widget
-// Copyright (C) 2000,2001 Kai Vehmanen (kaiv@wakkanet.fi)
+// Copyright (C) 200-2002 Kai Vehmanen (kai.vehmanen@wakkanet.fi)
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 // ------------------------------------------------------------------------
 
-#include <ecasound/eca-version.h>
+#include <eca-version.h>
 
 #include "qefile.h"
 #include "qestatusbar.h"
@@ -25,6 +25,8 @@
 #include "qeinterface.h"
 #include "version.h"
 
+using namespace std;
+
 QEInterface::QEInterface (const string& filename,
 			  QWidget *parent, 
 			  const char *name)
@@ -32,7 +34,7 @@ QEInterface::QEInterface (const string& filename,
 
   setCaption(string("ecawave " +
 		    ecawave_version + 
-		    " . (C) 1999-2001 Kai Vehmanen . ").c_str());
+		    " . (C) 1999-2003 Kai Vehmanen . ").c_str());
 
   session_repp = new QESession(this, 
 			       "session");
