@@ -1,6 +1,6 @@
 // ------------------------------------------------------------------------
 // qeobjectmap.cpp: Object map input widget
-// Copyright (C) 2000 Kai Vehmanen (kaiv@wakkanet.fi)
+// Copyright (C) 2000,2001 Kai Vehmanen (kaiv@wakkanet.fi)
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -17,6 +17,10 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 // ------------------------------------------------------------------------
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <qaccel.h>
 #include <qlayout.h>
 #include <qlistbox.h>
@@ -26,19 +30,31 @@
 #include <qhbox.h>
 #include <qgrid.h>
 
+#include <iostream>
+#include <list>
+#include <map>
 #include <string>
 
-#include <ecasound/eca-object.h>
-#include <ecasound/eca-object-map.h>
+#include <kvu_dbc.h>
+
+#include <eca-object.h>
+#include <eca-object-map.h>
+#include <eca-version.h>
 
 #include "qeobjectmap.h"
 
-QEObjectMap::QEObjectMap (ECA_OBJECT_MAP* omap, QWidget *parent, const char *name) 
+using std::list;
+using std::map;
+using std::string;
+
+QEObjectMap::QEObjectMap (const ECA_OBJECT_MAP* omap, QWidget *parent, const char *name) 
   : QEInput(parent, name),
     omap_rep(omap) {
   init_layout();
 }
 
+QEObjectMap::~QEObjectMap(void) { }
+
 void QEObjectMap::init_layout(void) {
   QBoxLayout* top = new QVBoxLayout(this);
 
@@ -46,10 +62,25 @@ void QEObjectMap::init_layout(void) {
   QListBox* objlist = new QListBox(objgroup, "objlist");
 
   empty_rep = false;
+  objlist->insertItem("<none>");
+
+#if ECA_LIBECASOUND_VERSION > 7
+  const list<string>& omap = omap_rep->registered_objects();
+  list<string>::const_iterator p = omap.begin();
+#else
   const map<string,string>& omap = omap_rep->registered_objects();
   map<string,string>::const_iterator p = omap.begin();
+#endif
   while(p != omap.end()) {
+#if ECA_LIBECASOUND_VERSION > 7
+    const ECA_OBJECT* obj = omap_rep->object(*p);
+    if (obj != 0) 
+      objlist->insertItem(obj->name().c_str());
+    else
+      objlist->insertItem(p->c_str());
+#else
     objlist->insertItem(p->second.c_str());
+#endif
     ++p;
   }
   if (omap.size() == 0) empty_rep = true;
@@ -64,24 +95,44 @@ void QEObjectMap::init_layout(void) {
 void QEObjectMap::update_results(void) {}
 void QEObjectMap::update_object(int index) {
   // --------
-  REQUIRE(index >= 0);
+  DBC_REQUIRE(index >= 0);
   // --------
 
   object_rep = 0;
+
+#if ECA_LIBECASOUND_VERSION > 7
+  const list<string>& omap = omap_rep->registered_objects();
+  list<string>::const_iterator p = omap.begin();
+#else
   const map<string,string>& omap = omap_rep->registered_objects();
-  int counter = 0;
   map<string,string>::const_iterator p = omap.begin();
-  while(p != omap.end()) {
-    if (counter == index) {
-      object_rep = dynamic_cast<ECA_OBJECT*>(omap_rep->object(p->first));
-      selected_index = counter;
-      emit changed();
+#endif
+  if (index > 0) { /* the first object is always null */
+    int counter = 1;
+    while(p != omap.end()) {
+      if (counter == index) {
+#if ECA_LIBECASOUND_VERSION > 7
+	object_rep = dynamic_cast<const ECA_OBJECT*>(omap_rep->object(*p));
+#else
+	object_rep = dynamic_cast<const ECA_OBJECT*>(omap_rep->object(p->first, false));
+#endif
+	if (object_rep == 0) {
+	  //  std::cerr << "(qeobjectmap) creation failed; " << *p << ".\n";
+	  empty_rep = true;
+	}
+	emit changed();
+      }
+      ++p;
+      ++counter;
     }
-    ++p;
-    ++counter;
+  }
+  else {
+    object_rep = 0;
+    empty_rep = true;
+    emit changed();
   }
 
   // --------
-  ENSURE(object_rep != 0 || empty_rep == true);
+  DBC_ENSURE(object_rep != 0 || empty_rep == true);
   // --------
 }
