@@ -1,5 +1,5 @@
-#ifndef _QEOBJECTINPUT_H
-#define _QEOBJECTINPUT_H
+#ifndef INCLUDED_QEOBJECTINPUT_H
+#define INCLUDED_QEOBJECTINPUT_H
 
 #include "qeinput.h"
 
@@ -18,14 +18,14 @@ class QEObjectMap : public QEInput {
   /**
    * Class constructor
    */
-  QEObjectMap (ECA_OBJECT_MAP* omap, QWidget *parent = 0, const char *name = 0);
+  QEObjectMap (const ECA_OBJECT_MAP* omap, QWidget *parent = 0, const char *name = 0);
 
-  ~QEObjectMap(void) { }
+  ~QEObjectMap(void);
 
   /**
    * Returns the currently selected object
    */
-  ECA_OBJECT* result(void) const { return(object_rep); }
+  const ECA_OBJECT* result(void) const { return(object_rep); }
 
   virtual bool class_invariant(void) const { return(omap_rep != 0); }
 
@@ -47,9 +47,8 @@ private slots:
 
  private:
 
-  ECA_OBJECT_MAP* omap_rep;
-  ECA_OBJECT* object_rep;
-  int selected_index;
+  const ECA_OBJECT_MAP* omap_rep;
+  const ECA_OBJECT* object_rep;
   bool empty_rep;
 
   /**
