@@ -1,12 +1,13 @@
-#ifndef _QEOPENFILEDIALOG_H
-#define _QEOPENFILEDIALOG_H
+#ifndef INCLUDED_QEOPENFILEDIALOG_H
+#define INCLUDED_QEOPENFILEDIALOG_H
+
+#include <string>
 
 #include <qdialog.h>
 #include <qcheckbox.h>
 #include <qlayout.h>
 
-#include <vector>
-#include <string>
+#include <eca-audio-format.h>
 
 #include "qeaudioformatinput.h"
 #include "qefilenameinput.h"
@@ -32,12 +33,10 @@ private slots:
 
  public:
 
-  string result_filename(void) const { return(fname->result_filename()); }
-  const string& current_dir(void) const { return(fname->current_dir()); }
+  std::string result_filename(void) const { return(fname->result_filename()); }
+  const std::string& current_dir(void) const { return(fname->current_dir()); }
 
-  int result_bits(void) const { return(aformat->bits()); }
-  int result_channels(void) const { return(aformat->channels()); }
-  int result_srate(void) const { return(aformat->samples_per_second()); }
+  ECA_AUDIO_FORMAT result_audio_format(void) const;
 
   bool result_wave_cache_toggle(void) const { return(wcache_toggle->isChecked()); }
   bool result_cache_refresh_toggle(void) const { return(refresh_toggle->isChecked()); }
