@@ -17,8 +17,12 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 // ------------------------------------------------------------------------
 
+#include <string>
+
 #include "qepasteevent.h"
 
+using std::string;
+
 QEPasteEvent::QEPasteEvent(ECA_CONTROL* ctrl,
 			   const string& input,
 			   const string& output,
