@@ -17,10 +17,12 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 // ------------------------------------------------------------------------
 
-#include <ecasound/eca-debug.h>
+#include <string>
 
 #include "qesaveevent.h"
 
+using std::string;
+
 QESaveEvent::QESaveEvent(ECA_CONTROL* ctrl,
 			 const string& input,
 			 const string& output)
