@@ -1,12 +1,11 @@
-#ifndef _QESAVEFILEDIALOG_H
-#define _QESAVEFILEDIALOG_H
+#ifndef INCLUDED_QESAVEFILEDIALOG_H
+#define INCLUDED_QESAVEFILEDIALOG_H
+
+#include <string>
 
 #include <qdialog.h>
 #include <qlayout.h>
 
-#include <vector>
-#include <string>
-
 #include "qefilenameinput.h"
 #include "qeacceptinput.h"
 
@@ -24,8 +23,8 @@ class QESaveFileDialog : public QDialog {
 
  public:
 
-  string result_filename(void) const { return(fname->result_filename()); }
-  const string& current_dir(void) const { return(fname->current_dir()); }
+  std::string result_filename(void) const { return(fname->result_filename()); }
+  const std::string& current_dir(void) const { return(fname->current_dir()); }
 
  private:
 
