@@ -17,12 +17,16 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 // ------------------------------------------------------------------------
 
+#include <string>
+
 #include <qstatusbar.h>
 #include <qtimer.h>
 
 #include "qestatusbar.h"
 #include "version.h"
 
+using namespace std;
+
 QEStatusBar::QEStatusBar (QWidget *parent, 
 			  const char *name)
   : QStatusBar( parent, name ) {
