@@ -1,7 +1,7 @@
-#ifndef _ECAWAVE_RESOURCES_H
-#define _ECAWAVE_RESOURCES_H
+#ifndef INCLUDED_QERESOURCES_H
+#define INCLUDED_QERESOURCES_H
 
-#include <ecasound/resource-file.h>
+#include <resource-file.h>
 
 /**
  * Class for representing ecawave user settings (~/.ecawaverc)
